"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiGatewayEnvelope = void 0;
const errors_js_1 = require("../errors.js");
const apigw_js_1 = require("../schemas/apigw.js");
const envelope_js_1 = require("./envelope.js");
/**
 * API Gateway envelope to extract data within body key
 */
exports.ApiGatewayEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'object',
    parse(data, schema) {
        return envelope_js_1.Envelope.parse(apigw_js_1.APIGatewayProxyEventSchema.parse(data).body, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = apigw_js_1.APIGatewayProxyEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse ApiGatewayEnvelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = envelope_js_1.Envelope.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse ApiGatewayEnvelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    },
};
