"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiGatewayV2Envelope = void 0;
const errors_js_1 = require("../errors.js");
const apigwv2_js_1 = require("../schemas/apigwv2.js");
const envelope_js_1 = require("./envelope.js");
/**
 * API Gateway V2 envelope to extract data within body key
 */
exports.ApiGatewayV2Envelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'object',
    parse(data, schema) {
        return envelope_js_1.Envelope.parse(apigwv2_js_1.APIGatewayProxyEventV2Schema.parse(data).body, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = apigwv2_js_1.APIGatewayProxyEventV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse API Gateway V2 envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = envelope_js_1.Envelope.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse API Gateway V2 envelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        // use type assertion to avoid type check, we know it's success here
        return parsedBody;
    },
};
