"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventBridgeEnvelope = void 0;
const errors_js_1 = require("../errors.js");
const index_js_1 = require("../schemas/index.js");
const envelope_js_1 = require("./envelope.js");
/**
 * Envelope for EventBridge schema that extracts and parses data from the `detail` key.
 */
exports.EventBridgeEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'object',
    parse(data, schema) {
        return envelope_js_1.Envelope.parse(index_js_1.EventBridgeSchema.parse(data).detail, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = index_js_1.EventBridgeSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse EventBridge envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedDetail = envelope_js_1.Envelope.safeParse(parsedEnvelope.data.detail, schema);
        if (!parsedDetail.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse EventBridge envelope detail', {
                    cause: parsedDetail.error,
                }),
                originalEvent: data,
            };
        }
        return parsedDetail;
    },
};
