"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VpcLatticeV2Envelope = void 0;
const errors_js_1 = require("../errors.js");
const index_js_1 = require("../schemas/index.js");
const envelope_js_1 = require("./envelope.js");
/**
 * Amazon VPC Lattice envelope to extract data within body key
 */
exports.VpcLatticeV2Envelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'object',
    parse(data, schema) {
        const parsedEnvelope = index_js_1.VpcLatticeV2Schema.parse(data);
        return envelope_js_1.Envelope.parse(parsedEnvelope.body, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = index_js_1.VpcLatticeV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse VpcLatticeV2 envelope.', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = envelope_js_1.Envelope.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse VpcLatticeV2 body.', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    },
};
