import { z } from 'zod';
declare const DynamoDBStreamChangeRecord: z.ZodObject<{
    ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
    Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
    NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    SequenceNumber: z.ZodString;
    SizeBytes: z.ZodNumber;
    StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
}, "strip", z.ZodTypeAny, {
    Keys: Record<string, Record<string, any>>;
    SequenceNumber: string;
    SizeBytes: number;
    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
    ApproximateCreationDateTime?: number | undefined;
    NewImage?: Record<string, any> | undefined;
    OldImage?: Record<string, any> | undefined;
}, {
    Keys: Record<string, Record<string, any>>;
    SequenceNumber: string;
    SizeBytes: number;
    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
    ApproximateCreationDateTime?: number | undefined;
    NewImage?: Record<string, any> | undefined;
    OldImage?: Record<string, any> | undefined;
}>;
declare const UserIdentity: z.ZodObject<{
    type: z.ZodEnum<["Service"]>;
    principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
}, "strip", z.ZodTypeAny, {
    type: "Service";
    principalId: "dynamodb.amazonaws.com";
}, {
    type: "Service";
    principalId: "dynamodb.amazonaws.com";
}>;
declare const DynamoDBStreamRecord: z.ZodObject<{
    eventID: z.ZodString;
    eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
    eventVersion: z.ZodString;
    eventSource: z.ZodLiteral<"aws:dynamodb">;
    awsRegion: z.ZodString;
    eventSourceARN: z.ZodString;
    dynamodb: z.ZodObject<{
        ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
        Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
        NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        SequenceNumber: z.ZodString;
        SizeBytes: z.ZodNumber;
        StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
    }, "strip", z.ZodTypeAny, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }>;
    userIdentity: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["Service"]>;
        principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
    }, "strip", z.ZodTypeAny, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }>>;
}, "strip", z.ZodTypeAny, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventVersion: string;
    eventSource: "aws:dynamodb";
    awsRegion: string;
    eventSourceARN: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | undefined;
}, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventVersion: string;
    eventSource: "aws:dynamodb";
    awsRegion: string;
    eventSourceARN: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | undefined;
}>;
declare const DynamoDBStreamToKinesisRecord: z.ZodObject<Omit<z.objectUtil.extendShape<{
    eventID: z.ZodString;
    eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
    eventVersion: z.ZodString;
    eventSource: z.ZodLiteral<"aws:dynamodb">;
    awsRegion: z.ZodString;
    eventSourceARN: z.ZodString;
    dynamodb: z.ZodObject<{
        ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
        Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
        NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        SequenceNumber: z.ZodString;
        SizeBytes: z.ZodNumber;
        StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
    }, "strip", z.ZodTypeAny, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }>;
    userIdentity: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["Service"]>;
        principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
    }, "strip", z.ZodTypeAny, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }>>;
}, {
    recordFormat: z.ZodLiteral<"application/json">;
    tableName: z.ZodString;
    userIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        type: z.ZodEnum<["Service"]>;
        principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
    }, "strip", z.ZodTypeAny, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }>>>;
    dynamodb: z.ZodObject<Omit<{
        ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
        Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
        NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        SequenceNumber: z.ZodString;
        SizeBytes: z.ZodNumber;
        StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
    }, "SequenceNumber" | "StreamViewType">, "strip", z.ZodTypeAny, {
        Keys: Record<string, Record<string, any>>;
        SizeBytes: number;
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }, {
        Keys: Record<string, Record<string, any>>;
        SizeBytes: number;
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }>;
}>, "eventVersion" | "eventSourceARN">, "strip", z.ZodTypeAny, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventSource: "aws:dynamodb";
    awsRegion: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SizeBytes: number;
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    recordFormat: "application/json";
    tableName: string;
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | null | undefined;
}, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventSource: "aws:dynamodb";
    awsRegion: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SizeBytes: number;
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    recordFormat: "application/json";
    tableName: string;
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | null | undefined;
}>;
/**
 * Zod schema for Amazon DynamoDB Stream event.
 *
 * @example
 * ```json
 * {
 *   "Records": [
 *     {
 *       "eventID": "1",
 *       "eventVersion": "1.0",
 *       "dynamodb": {
 *         "ApproximateCreationDateTime": 1693997155.0,
 *         "Keys": {
 *           "Id": {
 *             "N": "101"
 *           }
 *         },
 *         "NewImage": {
 *           "Message": {
 *             "S": "New item!"
 *           },
 *           "Id": {
 *             "N": "101"
 *           }
 *         },
 *         "StreamViewType": "NEW_AND_OLD_IMAGES",
 *         "SequenceNumber": "111",
 *         "SizeBytes": 26
 *       },
 *       "awsRegion": "us-west-2",
 *       "eventName": "INSERT",
 *       "eventSourceARN": "eventsource_arn",
 *       "eventSource": "aws:dynamodb"
 *     },
 *     {
 *       "eventID": "2",
 *       "eventVersion": "1.0",
 *       "dynamodb": {
 *         "OldImage": {
 *           "Message": {
 *             "S": "New item!"
 *           },
 *           "Id": {
 *             "N": "101"
 *           }
 *         },
 *         "SequenceNumber": "222",
 *         "Keys": {
 *           "Id": {
 *             "N": "101"
 *           }
 *         },
 *         "SizeBytes": 59,
 *         "NewImage": {
 *           "Message": {
 *             "S": "This item has changed"
 *           },
 *           "Id": {
 *             "N": "101"
 *           }
 *         },
 *         "StreamViewType": "NEW_AND_OLD_IMAGES"
 *       },
 *       "awsRegion": "us-west-2",
 *       "eventName": "MODIFY",
 *       "eventSourceARN": "source_arn",
 *       "eventSource": "aws:dynamodb"
 *     }
 *   ]
 * }
 * ```
 *
 * @see {@link types.DynamoDBStreamEvent | DynamoDBStreamEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html}
 */
declare const DynamoDBStreamSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventID: z.ZodString;
        eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
        eventVersion: z.ZodString;
        eventSource: z.ZodLiteral<"aws:dynamodb">;
        awsRegion: z.ZodString;
        eventSourceARN: z.ZodString;
        dynamodb: z.ZodObject<{
            ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
            Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
            NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            SequenceNumber: z.ZodString;
            SizeBytes: z.ZodNumber;
            StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
        }, "strip", z.ZodTypeAny, {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        }, {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        }>;
        userIdentity: z.ZodOptional<z.ZodObject<{
            type: z.ZodEnum<["Service"]>;
            principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
        }, "strip", z.ZodTypeAny, {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        }, {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        }>>;
    }, "strip", z.ZodTypeAny, {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }, {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }[];
}, {
    Records: {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }[];
}>;
export { DynamoDBStreamToKinesisRecord, DynamoDBStreamSchema, DynamoDBStreamRecord, DynamoDBStreamChangeRecord, UserIdentity, };
//# sourceMappingURL=dynamodb.d.ts.map