import { ParseError } from '../errors.js';
import { APIGatewayProxyEventSchema } from '../schemas/apigw.js';
import { Envelope, envelopeDiscriminator } from './envelope.js';
/**
 * API Gateway envelope to extract data within body key
 */
export const ApiGatewayEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelopeDiscriminator]: 'object',
    parse(data, schema) {
        return Envelope.parse(APIGatewayProxyEventSchema.parse(data).body, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = APIGatewayProxyEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse ApiGatewayEnvelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = Envelope.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse ApiGatewayEnvelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    },
};
