import type { ZodSchema, z } from 'zod';
import type { ParsedResult } from '../types/index.js';
import { envelopeDiscriminator } from './envelope.js';
/**
 * CloudWatch Envelope to extract a List of log records.
 *
 *  The record's body parameter is a string (after being base64 decoded and gzipped),
 *  though it can also be a JSON encoded string.
 *  Regardless of its type it'll be parsed into a BaseModel object.
 *
 *  Note: The record will be parsed the same way so if model is str
 */
export declare const CloudWatchEnvelope: {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelopeDiscriminator]: "array";
    parse<T extends ZodSchema>(data: unknown, schema: T): z.infer<T>[];
    safeParse<T extends ZodSchema>(data: unknown, schema: T): ParsedResult<unknown, z.infer<T>[]>;
};
//# sourceMappingURL=cloudwatch.d.ts.map