import { ParseError } from '../errors.js';
import { EventBridgeSchema } from '../schemas/index.js';
import { Envelope, envelopeDiscriminator } from './envelope.js';
/**
 * Envelope for EventBridge schema that extracts and parses data from the `detail` key.
 */
export const EventBridgeEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelopeDiscriminator]: 'object',
    parse(data, schema) {
        return Envelope.parse(EventBridgeSchema.parse(data).detail, schema);
    },
    safeParse(data, schema) {
        const parsedEnvelope = EventBridgeSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse EventBridge envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedDetail = Envelope.safeParse(parsedEnvelope.data.detail, schema);
        if (!parsedDetail.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse EventBridge envelope detail', {
                    cause: parsedDetail.error,
                }),
                originalEvent: data,
            };
        }
        return parsedDetail;
    },
};
